/*
 * Copyright 2012-2017 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.gateway.common.db.servlet;

import com.redhat.thermostat.gateway.common.core.servlet.CommonQueryParams;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.core.Response;

public interface HttpHandlerHelper {

    /*
     *  HTTP DELETE handling
     */
    Response handleDelete(HttpServletRequest httpServletRequest,
            ServletContext context, String queries, boolean returnMetadata);

    Response handleDeleteWithJvmID(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String jvmId, String queries, boolean returnMetadata);

    Response handleDeleteWithSystemID(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String queries, boolean returnMetadata);

    /*
     *  HTTP GET handling
     */
    Response handleGetWithSystemID(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, CommonQueryParams params);

    Response handleGetWithJvmID(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String jvmId, CommonQueryParams params);

    Response handleGet(HttpServletRequest httpServletRequest,
            ServletContext context, CommonQueryParams params);

    Response handleGet(HttpServletRequest httpServletRequest,
            ServletContext context, String queries, CommonQueryParams params);

    /*
     *  HTTP POST handling
     */
    Response handlePost(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String jvmId, boolean returnMetadata, String body);

    Response handlePostWithJvmID(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String jvmId, boolean returnMetadata, String body);

    Response handlePostWithSystemID(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, boolean returnMetadata, String body);

    /*
     *  HTTP PUT handling
     */
    Response handlePut(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String jvmId, String queries, boolean returnMetadata, String body);

    Response handlePutWithJvmId(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String jvmId, String queries, boolean metadata, String body);

    Response handlePutWithSystemId(HttpServletRequest httpServletRequest,
            ServletContext context, String systemId, String queries, boolean metadata, String body);
}
